C*	QXCAT	- GET CONCATENATED LIST STAT TOTAL IF /FU SPECIFIED
C
	SUBROUTINE QXCAT (BUFO, IPGCNT, TIME)
C
C	BUFO	= BUFFER TO ENCODE RESULTS TO
C	IPGCNT	= ACCUMULATED PAGES
C	TIME	= ACCUMULATED TIME
C
	INCLUDE 'QXCM.COM/NOLIST'
C
	DIMENSION BUFO(10), BTEMP(32)
	DATA BTEMP(32)/0/
C
C	IF /CC SPECIFIED THEN DON'T DO ANYTHING
C
	IF (LSWEC .OR. NEXTAD.EQ.0) GO TO 400
C
C	LINK THROUGH THE CONCATENATED LIST AND SUM UP PAGES AND TIMES
C
 100	CONTINUE
	CALL QXNXE (LEOL)
	CALL QXBE (BTEMP)
	CALL QXPC (BTEMP, IENT(QDEV/2), BENT(QUNIT),
	1	TCHR, TLNCT, IPGT, TIMET)
	IPGCNT = IPGCNT + MAX0(0, IPGT)		! IF ERROR CODE DON'T ADD IT
	TIME = TIME + AMAX1(0.0, TIMET)
	IF (NEXTAD .NE. 0) GO TO 100		! END OF CAT LIST ?
C
C	ENCODE THE RESULTS
C
	ENCODE (10, 520, BUFO) IPGCNT, TIME
 520	FORMAT (I3,1X,F6.1)
C
 400	CONTINUE
	RETURN
	END
